package dev.fyloz.colorrecipesexplorer.rest.account

import dev.fyloz.colorrecipesexplorer.Constants
import dev.fyloz.colorrecipesexplorer.config.annotations.PreAuthorizeAdmin
import dev.fyloz.colorrecipesexplorer.dtos.account.GroupTokenSaveDto
import dev.fyloz.colorrecipesexplorer.logic.account.GroupTokenLogic
import dev.fyloz.colorrecipesexplorer.rest.created
import dev.fyloz.colorrecipesexplorer.rest.noContent
import dev.fyloz.colorrecipesexplorer.rest.ok
import org.springframework.context.annotation.Profile
import org.springframework.web.bind.annotation.DeleteMapping
import org.springframework.web.bind.annotation.GetMapping
import org.springframework.web.bind.annotation.PathVariable
import org.springframework.web.bind.annotation.PostMapping
import org.springframework.web.bind.annotation.RequestBody
import org.springframework.web.bind.annotation.RequestMapping
import org.springframework.web.bind.annotation.RestController
import javax.validation.Valid

@RestController
@RequestMapping(Constants.ControllerPaths.GROUP_TOKEN)
@PreAuthorizeAdmin
@Profile("!emergency")
class GroupTokenController(private val groupTokenLogic: GroupTokenLogic) {
    @GetMapping
    fun getAll() = ok(groupTokenLogic.getAll())

    @GetMapping("{id}")
    fun getById(@PathVariable id: String) = ok(groupTokenLogic.getById(id))

    @PostMapping
    fun save(@RequestBody @Valid dto: GroupTokenSaveDto) = with(groupTokenLogic.save(dto)) {
        created(Constants.ControllerPaths.GROUP_TOKEN, this, this.id)
    }

    @DeleteMapping("{id}")
    fun deleteById(@PathVariable id: String) = noContent {
        groupTokenLogic.deleteById(id)
    }
}
